@@ -73,23 +73,6 @@ interpolate('jspell.pc.in','jspell.pc',%c_config);
 my $cc = ExtUtils::CBuilder->new(quiet => 0);
 
 
-### AGREP
-print "\nCompiling agrep.\n";
-my @agrep_source = qw~asearch.c    asearch1.c     bitap.c     checkfile.c
-                      compat.c     follow.c       main.c       maskgen.c
-                      mgrep.c      parse.c        preprocess.c
-                      sgrep.c      utilities.c~;
-my @agrep_objects = map {
-		print " - agrep/$_\n";
-		$cc->compile(   source => "agrep/$_")} @agrep_source;
-		
-print " - building [agrep] binary\n";
-$cc->link_executable(objects  => [@agrep_objects],
-					 exe_file => "agrep/agrep");
-
-
-
-
 ### JSpell
 print "\nCompiling Jspell.\n";
 
@@ -122,12 +105,12 @@ $cc->link(extra_linker_flags => "$LCURSES$CCURSES",
 
 print " - building [jspell] binary\n";
 $cc->link_executable(extra_linker_flags => "$LCURSES$CCURSES",
-                     objects => [@jspell_shared,'src/jmain.o'],  
+                     objects => [@jspell_shared, 'src/jmain.o'],  
                      exe_file => "src/jspell");
 					 
 print " - building [jbuild] binary\n";
 $cc->link_executable(extra_linker_flags => "$LCURSES$CCURSES",
-                     objects => [@jspell_shared,'src/jbuild.o'], 
+                     objects => [@jspell_shared, 'src/jbuild.o'], 
                      exe_file => "src/jbuild");
 
 print "\nBuilt International Jspell $VERSION.\n";
